#
# spec file for package python-rpyc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-rpyc%{psuffix}
Version:        4.1.5
Release:        bp154.1.29
Summary:        Remote Python Call (RPyC), a RPC library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/tomerfiliba/rpyc
Source:         https://github.com/tomerfiliba/rpyc/archive/%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-plumbum >= 1.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module plumbum >= 1.2}
BuildRequires:  %{python_module rpyc = %{version}}
%endif
%python_subpackages

%description
RPyC (pronounced like "are-pie-see"), or Remote Python Call, is a
transparent library for symmetrical remote procedure calls,
clustering, and distributed-computing.  RPyC makes use of
object-proxying, a technique that employs python's dynamic nature, to
overcome the physical boundaries between processes and computers, so
that remote objects can be manipulated as if they were local.

%prep
%setup -q -n rpyc-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

mv %{buildroot}%{_bindir}/rpyc_classic.py %{buildroot}%{_bindir}/rpyc_classic
mv %{buildroot}%{_bindir}/rpyc_registry.py %{buildroot}%{_bindir}/rpyc_registry

%python_clone -a %{buildroot}%{_bindir}/rpyc_classic
%python_clone -a %{buildroot}%{_bindir}/rpyc_registry
%endif

%if %{with test}
%check
%python_expand nosetests-%{$python_bin_suffix} -v -I test_deploy -I test_gevent_server -I test_ssh -I test_registry -I test_win32pipes
%endif

%if !%{with test}
%post
%{python_install_alternative rpyc_classic rpyc_registry}

%postun
%python_uninstall_alternative rpyc_classic

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/rpyc_classic
%python_alternative %{_bindir}/rpyc_registry
%{python_sitelib}/*
%endif

%changelog
* Fri May 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.1.5:
  * Fixed mutable object used as kwarg for Server ctor
  * Corrections to teleport example
  * Lowered GIL-lock acquires for <64kb within channel sends to address slowness
* Thu Mar 19 2020 pgajdos@suse.com
- version update to 4.1.4
  - Merged 3.7 and 3.8 teleportatio compat enhancement `#371`_
  - Fixed connection hanging due to namepack cursor  `#369`_
  - Fixed test dependencies and is_py_* for 3.9
  - Performance improvements: `#366`_ and `#351`_
  - Merged fix for propagate_KeyboardInterrupt_locally `#364`_
  - Fixed handling of exceptions for request callbacks `#365`_
  - Partially fixed return value for netref.__class__ `#355`_
  - Fixed bsc#1152987 `CVE-2019-16328`_ which was caused by a missing protocol security check
  - Fixed RPyC over RPyC for mutable parameters and extended unit testing for `#346`_
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.1.1:
  * Fixed netref.class_factory id_pack usage per #339 and added test cases
  * Name pack casted in _unbox to fix IronPython bug. Fixed #337
  * Increased chunk size to improve multi-client response time and throughput of large data #329
  * Added warning to _remote_tb when the major version of local and remote mismatch (#332)
  * OneShotServer termination was fixed by WilliamBruneau (#343)
  * Known issue with 3.8 for CodeType parameters (may drop Python2 support first)
* Wed Jun 12 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 4.1.0
  * Added connection back-off and attempts for congested workloads
  * Cross-connection instance check for cached netref classes
* Wed Jun  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix test execution to make sure we run it under all interpreters
* Fri May 24 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 4.0.2
  * fix default hostname for ipv6 in rpyc_classic.py
  * fix ThreadPoolServer not working
  4.0.1
  * fix ValueError during install due to absolute PATH in SOURCES.txt
  4.0.0 (see upstream Release Change Log for more)
  * classic.teleport_function now executes the function in the
    connection’s namespace by default
  * Changed signature of Service.on_connect and on_disconnect,
    adding the connection as argument.
  * Changed signature of Service.__init__, removing the connection
    argument
  * no longer store connection as self._conn.
  * SlaveService is now split into two asymetric classes:
    SlaveService and MasterService. If you want old SlaveService
    behaviour, use ClassicService
  * Removed modules rpyc.experimental.splitbrain and rpyc.experimental.retunnel.
  * bin/rpyc_classic.py will bind to 127.0.0.1 instead of 0.0.0.0 by default
  * Exposed attributes no longer hide plain attributes if one
    otherwise has the required permissions to access the plain attribute.
  * teleported functions will now be defined by default in the
    globals dict
  * fix deadlock with connections talking to each other multithreadedly
  * handle timeouts cumulatively
  * fix __hash__ for netrefs
  * add gevent Server. For now, this requires using gevent.monkey.patch_all()
    before importing for rpyc. Client connections can already be made
    without further changes to rpyc, just using gevent’s monkey patching.
  * fix problem with MongoDB, or more generally any remote objects
    that have a catch-all __getattr__
  * service can now easily override protocol handlers, by updating
    conn._HANDLERS in _connect or on_connect.
- implement multibuild to fix some tests, skip some other failing tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 3.4.4
  * Fix refcount leakage when unboxing from cache (`#196`_)
  * Fix TypeError when dispatching exceptions on py2 (unicode)
  * Respect ``rpyc_protocol_config`` for default Service getattr
  * Support unix domain sockets
  * Use first accessible server in ``connect_by_service``
  * Fix deadlock problem with logging
  * Fix timeout problem for long commands
- Update to 3.4.3
  * Add missing endpoints config in ThreadPoolServer
  * Fix jython support
  * Improve documentation
- Update to 3.4.2
  * Fix ``export_function`` on python 3.6
- Update to 3.4.1
  * Fix issue high-cpu polling
  * Fix filename argument in logging
  * Improved log messages
  * Drop support for python 3.2 and py 2.5
- Update to 3.4.0
  * Add keepalive interface
  * Various fixes
- Update to 3.3.0
  * RPyC integrates with `plumbum <http://pypi.python.org/pypi/plumbum>`_; plumbum is required
    for some features, like ``rpyc_classic.py`` and   *zero deploy  *, but the core of the library
    doesn't require it. It is, of course, advised to have it installed.
  * ``SshContext``, ``SshTunnel`` classes killed in favor of plumbum's SSH tunneling. The interface
    doesn't change much, except that ``ssh_connect`` now accept a ``plumbum.SshMachine`` instance
    instead of ``SshContext``.
  * Zero deploy: deploy RPyC to a remote machine over an SSH connection and form an SSH tunnel
    connected to it, in just one line of code. All you need is SSH access and a Python interpreter
    installed on the remote machine.
  * Dropping Python 2.4 support. RPyC now requires Python 2.5 - 3.3.
  * rpycd - a well-behaved daemon for ``rpyc_classic.py``, based on
    `python-daemon <http://pypi.python.org/pypi/python-daemon/>`_
  * The ``OneShotServer`` is now exposed by ``rpyc_classic -m oneshot``
  * ``scripts`` directory renamed ``bin``
  * Introducing ``Splitbrain Python`` - running code on remote machines transparently. Although tested,
    it is still considered experimental.
  * Removing the ``BgServerThread`` and all polling/timeout hacks in favor of a "global background
    reactor thread" that handles all incoming transport from all connections. This should solve
    all threading issues once and for all.
  * Added ``MockClassicConnection`` - a mock RPyC "connection" that allows you to write code that runs
    either locally or remotely without modification
  * Added ``teleport_function``
- spec file cleanups
- Use update-alternatives
- Update summary and conclusions
* Sun Mar 18 2018 afaerber@suse.de
- Convert to singlespec
  * Drop pre_checkin.sh
* Mon Jan 21 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 21 2013 p.drouand@gmail.com
- Update to version 3.2.3:
  * No changelog available
* Tue Mar 13 2012 jfunk@funktronics.ca
- Update to 3.2.1:
  * Adding missing import (#52)
  * Fixing site documentation issue (#54)
  * Fixing Python 3 incompatibilities (#58, #59, #60, #61, #66)
  * Fixing slice issue (#62)
  * Added the endpoints parameter to the config dict of connection (only on
    the server side)
* Thu Dec  8 2011 jfunk@funktronics.ca
- Update to 3.2.0
  - Added support for IPv6 (#28)
  - Added SSH tunneling support (ssh_connect)
  - Added restricted object wrapping
  - Several fixes to AsyncResult and weak references
  - Added the ThreadPoolServer
  - Fixed some minor (harmless) races that caused tracebacks occasionally when
    server-threads terminated
  - Fixes issues #8, #41, #42, #43, #46, and #49.
  - Converted all CRLF to LF (#40)
  - Dropped TLSlite integration (#45). We’ve been dragging this corpse for too
    long
  - New documentation (both the website and docstrings) written in Sphinx
  - Python 3.0-3.2 support
- 3.1.0
  - Supports CPython 2.4-2.7, IronPython, and Jython
  - tlslite has been ported to python 2.5-2.7 (the original library targeted
    2.3 and 2.4)
  - Initial python 3 support – not finished!
  - Moves to a more conventional directory structure
  - Moves to more standard facilities (logging, nosetests)
  - Solves a major performance issue with the BgServingThread (#32), by
    removing the contention between the two threads that share the connection
  - Fixes lots of issues concerning the ForkingServer (#3, #7, and #15)
  - Many small bug fixes (#16, #13, #4, etc.)
  - Integrates with the built-in ssl module for SSL support
  - rpyc_classic.py now takes several --ssl-xxx switches (see --help for more
    info)
  - Fixes typos, running pylint, etc.
  - Breakage from 3.0.7:
  - Removing egg builds (we’re pure python, and eggs just messed up the
    build)
  - Package layout changed drastically, and some files were renamed
  - The servers/ directory was renamed scripts/
  - classic_server.py was renamed rpyc_classic.py
  - They scripts now install to your python scripts directory (no longer
    part of the package), e.g. C:\python27\Scripts
  - rpyc_classic.py now takes --register in order to register, instead of
  - -dont-register, which was a silly choice
  - classic.tls_connect, factory.tls_connect were renamed tlslite_connect,
    to distinguish it from the new ssl_connect
* Thu Feb 18 2010 jfunk@funktronics.ca
- Update to 3.0.7
* Tue Jul 17 2007 James Oakley <jfunk@funktronics.ca> - 2.60-1
- Initial release
